@@ -1,12 +1,19 @@
 module Rack
 
-  class MockSession
+  class MockSession # :nodoc:
     attr_writer :cookie_jar
-    attr_reader :last_response
+    attr_reader :default_host
 
     def initialize(app, default_host = Rack::Test::DEFAULT_HOST)
       @app = app
+      @after_request = []
       @default_host = default_host
+      @last_request = nil
+      @last_response = nil
+    end
+
+    def after_request(&block)
+      @after_request << block
     end
 
     def clear_cookies
@@ -21,9 +28,13 @@ module Rack
       env["HTTP_COOKIE"] ||= cookie_jar.for(uri)
       @last_request = Rack::Request.new(env)
       status, headers, body = @app.call(@last_request.env)
+
       @last_response = MockResponse.new(status, headers, body, env["rack.errors"].flush)
+      body.close if body.respond_to?(:close)
+
       cookie_jar.merge(last_response.headers["Set-Cookie"], uri)
 
+      @after_request.each { |hook| hook.call }
       @last_response
     end
 
